[Pvfs2-cvs] commit by elaine in pvfs2/src/io/trove: trove.h
CVS commit program
cvs at parl.clemson.edu
Thu Mar 10 16:09:01 EST 2011
Update of /projects/cvsroot/pvfs2/src/io/trove
In directory parlweb1:/tmp/cvs-serv29811/src/io/trove
Modified Files:
Tag: Orange-Elaine-Distr-Dir-Branch
trove.h
Log Message:
Add a "type" field to keys in the keyval database so both directory
entries and attributes can be stored for dirdata handles.
Index: trove.h
===================================================================
RCS file: /projects/cvsroot/pvfs2/src/io/trove/trove.h,v
diff -p -u -r1.45.10.1.8.1 -r1.45.10.1.8.2
--- trove.h 5 Oct 2010 18:30:06 -0000 1.45.10.1.8.1
+++ trove.h 10 Mar 2011 21:09:01 -0000 1.45.10.1.8.2
@@ -61,7 +61,8 @@ enum
TROVE_DB_CACHE_SYS = 1 << 6,
TROVE_KEYVAL_HANDLE_COUNT = 1 << 7,
TROVE_BINARY_KEY = 1 << 8, /* tell trove this is a binary key */
- TROVE_KEYVAL_ITERATE_REMOVE = 1 << 9 /* tell trove to delete keyvals as it iterates */
+ TROVE_KEYVAL_ITERATE_REMOVE = 1 << 9, /* tell trove to delete keyvals as it iterates */
+ TROVE_KEYVAL_DIRECTORY_ENTRY = 1 << 10 /* tell trove to store this as a directory entry */
};
enum
More information about the Pvfs2-cvs
mailing list